#
# spec file for package openjph
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           openjph
Version:        0.21.1
Release:        1.1
Summary:        An implementation of JPEG2000 Part-15
License:        BSD-2-Clause
Group:          Productivity/Graphics/Convertors
URL:            https://github.com/aous72/OpenJPH
Source:         https://github.com/aous72/OpenJPH/archive/refs/tags/%{version}.tar.gz
BuildRequires:  cmake >= 3.10
BuildRequires:  gcc-c++
BuildRequires:  libtiff-devel

%description
This package contains libopenjph, a library implementing the JPEG-2000
standard Part 15.

%package -n libopenjph0_21
Summary:        JPEG-2000 Part-15 library
Group:          System/Libraries

%description -n libopenjph0_21
This is an implementation of High-throughput JPEG2000 (HTJ2K), also
known as JPH, JPEG2000 Part 15, ISO/IEC 15444-15, or ITU-T T.814.
Only the LGT 5/3 wavelet transform for lossless compression and the
CDF 9/7 wavelet transform for lossy compression are supported.

%package devel
Summary:        Development files for libopenjph, a JPEG-2000 Part 15 library
Group:          Development/Libraries/C and C++
Requires:       libjpeg-devel
Requires:       libopenjph0_21 = %{version}

%description devel
This package contains libopenjph, a library implementing the JPEG-2000
standard Part 15.

%prep
%autosetup -p1 -n OpenJPH-%{version}

%build
%ifarch x86_64
%cmake -DBUILD_SHARED_LIBS:BOOL=ON -DOJPH_DISABLE_INTEL_SIMD:BOOL=OFF
%else
%cmake -DBUILD_SHARED_LIBS:BOOL=ON -DOJPH_DISABLE_INTEL_SIMD:BOOL=ON
%endif

%cmake_build

%install
%cmake_install

%ldconfig_scriptlets -n libopenjph0_21

%files
%license LICENSE
%doc README.md
%{_bindir}/ojph_compress
%{_bindir}/ojph_expand

%files -n libopenjph0_21
%{_libdir}/libopenjph*.so.*

%files devel
%{_includedir}/openjph/
%{_libdir}/libopenjph.so
%{_libdir}/pkgconfig/openjph.pc
%{_libdir}/cmake/openjph/

%changelog
* Tue Feb 25 2025 Jan Engelhardt <jengelh@inai.de>
- Trim redundancies from descriptions and fix spellos
- Use SRPM base name for -devel subpackage
- Delete empty %%check
- Restore ldconfig calls
* Tue Feb 25 2025 Michael Vetter <mvetter@suse.com>
- Remove ldconfig scriptlets
- Hide specific cmake files and just list the dir
* Fri Feb 21 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.21.1:
  * This enables compilation for 32bit systems.
    I never intended to support 32bit properly; so, this version allows
    compilation for 32bit systems with many warnings.
    For Linux you need the -m32 flag. Run export CXXFLAGS="-m32" and
    export CXXFLAGS="-m32" before running cmake.
    To have TIFF support, you need the 32bit TIFF library. #181
  * Update CMakeLists.txt for config file naming convention in #180
* Mon Feb  3 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.21.0:
  * Added lossy compression to data samples that are originally floating
    point numbers, and that are undergoing non-linear type3 transform,
    which stored with the help of the NLT marker segment.
  * Better support for components with differing properties; these
    involve using the QCC and COC marker segments.  These are exposed
    using the API, but not in the applications.
  * OpenJPH can now be added using cmake's find_package().
  * For WASM, cmake configuration now generates one version only, with
    SIMD support; this support can be disabled through a command line option.
  * Fixes a bug when a resolution has one 64bit line. #162
  * Makes all colour components involved in colour transform employ the s… #163
  * Allow OpenJPH to be exported #166
  * Supporting differing components in QCD #169
  * Adding NLT implementation to the lossy path #170
  * This adds support for COC. #172
  * Add support for find_package(), clean-up EMCC support and clean-up TIFF support #173
  * Adding Support for WASM without SIMD. #174
  * This is a better way of packet header parsing. #176
  * Support for lossy floating point with NLT segment marker. #178
* Fri Dec 27 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.18.2:
  * This fixes a bug which wrongly sets implementation precision #161
* Fri Dec 27 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.18.1:
  This addresses the illegal instruction issue when -flto flag is used
  (link time optimization) as details in this thread:
  https://bugzilla.redhat.com/show_bug.cgi?id=2307795
  See #160
* Wed Nov 27 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.18.0:
  * This release adds support for 32bit lossless compression of integer and
    floating-point data, where floating-point data can benefit from the
    non-linear (NLT) segment marker, which represent negative values in a more
    compression-friendly format.
    This required the addition of 64 bit processing path for lossless
    compression, which is automatically employed if needed.
  * This version also addresses issue #157, which causes illegal instruction
    fault on machines that do not support AVX or more recent instruction sets,
    when the code in compiled with clang and in the Release mode only.
* Mon Sep 23 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.17.0:
  * Adding support for NLT marker segment of type 3.
    The code is not very complete, but it is in a useful state
    for publishing.  To make use of the NLT marker segment for
    type 3, partial support for the .pfm file format has been added.
    For .pfm files, lossy compression is not supported -- it is
    possible to add support at some future point.  Reversible coding
    of .pfm files is supported, where the NLT marker is automatically inserted.
    However, the current implementation supports only 28-bit
    for encoding 27-bit for decoding.  Therefore floating point
    values stored in a .pfm file, which are 32-bit, need to be truncated.
    Using the '-bit_depth' option, ojph_compress can perform this truncation.
    'ojph_compress' should work correctly with codestreams generated
    with ojph_compress, converting truncated values
    back to normal floating point values.
  * Adding support for NLT marker segment of type 3 #154
* Mon Sep  9 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.16.0:
  * Add AVX2 support for block encoding and decoding.
  * Fix what I think is a bug in AVX512 block encoding.
  * Add avx2 optimization for encoder and decoder #153.
* Mon Jul 22 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.15.0:
  * This addresses a few small issues #146, #147, and #148.
    The most important changes are:
  * Added "-fexceptions" flag to subprojects/js/CMakeLists.txt, which I forgot to do.
  * Added a function "set_message_level()" to ojph_message.h, which
    controls the severity level at which info/warn/error messages are printed.
    By adjusting the message level, users can tailor the verbosity of the
    output to their specific needs.
* Thu Jul  4 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.14.2:
  * This should fix installation folders for both relative and
    absolute folders
* Wed Jul  3 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.14.1:
  * Fix includedir/libdir in pkg-config file when
    CMAKE_INSTALL_INCLUDEDIR/CMAKE_INSTALL_LIBDIR are absolute
    paths #145
* Thu Jun 20 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.14.0:
  * Fix a mistake in the last commit. #141
  * doc: trivial typo fixes #143
  * Add some documentation and a bug fix. #144
* Wed May 22 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.13.3:
  * Fixes a mistake
* Wed May 22 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.13.2:
  * Better preprocessor directives for ARM, supports 32 and 64 bits.
    This also sets the default memory to 128MB for WASM-based javascript
    programs in the subprojects/js directory.
* Wed May 15 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.13.1:
  * This is a small change to the preprocess settings
    + It removes defining OJPH_DISABLE_SIMD by default for ARM.
    + It prevents defining OJPH_DISABLE_SIMD twice, which may happen
    when building for WASM.
* Fri May  3 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.13.0:
  * Add options to disable instruction sets #111 and #121.
  * Better arm support #139.
* Tue Apr 30 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.12.0:
  * doc: trivial typo fixes #136
  * Adding a simple RTP client that is compliant with
    draft-ietf-avtcore-rtp-j2k-scl-00 #137
* Mon Apr 15 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.11.0:
  * This removes the hardcoded TIFF_PATH, must use CMAKE_PREFIX_PATH.
  * Adding DFS support and partial support for ATK to support
    low-latency HTJ2K images
* Tue Feb 13 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.10.5:
  * This release addresses issues #127 and #128
* Thu Feb  8 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.10.4:
  * Add getter for TLM marker request #118
  * Make comment_exchange string const #119
  * Add accessors for tilepart division #120
  * Include ojph_arch.h in ojph_codestream.h and ojph_params.h to
  compensate for OJPH_EXPORT definition #123
  * Update ojph_codestream_local.cpp, fix typo #124
  * This fixes tile_size calculation. #125
  * Fixing irv97 transform #126
* Tue Jan  9 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.10.3:
  * Another change to CMakeLists.txt to better handle PKG-Config
* Mon Jan  8 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.10.2:
  * Small modification to PKG-Config Setting
* Mon Jan  8 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.10.1:
  * Add library path to pkg-config file #116
* Sat Jan  6 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.10.0:
  * Refactor codestream_local into multiple source/header files #93
  * Options to insert a TLM marker, and create tileparts #87
  * Adds AVX512 support #103
  * Walk around overflow when block width is bigger than 64 #104
  * Add support for writing a user-specified COM marker #105
  * CMake tweaks -- Adding a CMake option to disable building
    executables. #109
  * Feature - dpx file input support for ojph_compress #110
  * Improving the way CMakeLists.txt files are arranged, and also
    addressing issues with building for MinGW and MSYS. #115
* Thu Dec 21 2023 Michael Vetter <mvetter@suse.com>
- Initial package of openjph 0.9.0 for openSUSE
